import subprocess
import re

PPP_IP_FILE = '/root/ppp-ip.txt'  # ppp接口名称和IP对应关系的文件路径
PPP_CURL_FILE = '/root/ppp-curl.txt'  # 记录不一致或不存在的PPP接口的文件路径

def get_ppp_interfaces_with_ip():
    """获取系统中ppp接口名称和对应的IP地址"""
    try:
        output = subprocess.check_output('ip address | grep inet', shell=True).decode('utf-8')
        print("Output of 'ip address | grep inet' command:")
        print(output)

        interface_ip_mapping = {}
        lines = output.split('\n')
        for line in lines:
            match = re.search(r'inet (\S+).* global ppp(\d+)', line)
            if match:
                ip = match.group(1)
                interface = f"ppp{match.group(2)}"
                interface_ip_mapping[interface] = ip
        print(f"Detected ppp interfaces with IP addresses: {interface_ip_mapping}")
        return interface_ip_mapping
    except subprocess.CalledProcessError as e:
        print(f"Error getting ppp interfaces with IP addresses: {e}")
        return {}

def write_ppp_ip_to_file(interface_ip_mapping):
    """将ppp接口名称和IP对应关系写入文件"""
    try:
        with open(PPP_IP_FILE, 'w') as file:
            for interface, ip in interface_ip_mapping.items():
                file.write(f"{interface} {ip}\n")
        print(f"PPPIp file {PPP_IP_FILE} updated.")
    except Exception as e:
        print(f"Error updating PPPIp file {PPP_IP_FILE}: {e}")

def compare_and_update_files(interface_ip_mapping):
    """比较系统中的PPP接口和IP地址，更新文件"""
    try:
        with open(PPP_IP_FILE, 'r') as file:
            existing_mapping = {}
            for line in file:
                interface, ip = line.strip().split()
                existing_mapping[interface] = ip

        # 检查接口名称和IP地址是否一致，如果不一致或不存在，则记录到PPP-Curl文件中
        with open(PPP_CURL_FILE, 'w') as file:
            for interface, ip in interface_ip_mapping.items():
                if interface not in existing_mapping or existing_mapping[interface] != ip:
                    file.write(f"{interface} {ip}\n")

    except Exception as e:
        print(f"Error comparing and updating files: {e}")

def main():
    # 获取系统中的ppp接口名称和对应的IP地址
    interface_ip_mapping = get_ppp_interfaces_with_ip()
    if not interface_ip_mapping:
        print("No ppp interfaces found with IP addresses")
        return

    # 比较系统中的PPP接口和IP地址，更新文件
    compare_and_update_files(interface_ip_mapping)

    # 将ppp接口名称和对应的IP地址写入文件
    write_ppp_ip_to_file(interface_ip_mapping)

if __name__ == "__main__":
    main()
